;=============================================================================
; Original MOD file: "monkey.mod"
; Original MOD name: "monkey island       "
; ASM file created by Mod2PSG V1.7 by Martin Konrad (mkon@gmx.de)
;=============================================================================



;=============================================================================
; Constants
;=============================================================================
RAM_START    = $C000
CONTROL_PORT = $DC
GAME_GEAR_STEREO_SOUND_PORT = $06

;=============================================================================
; PSGMOD variables
;=============================================================================
PSGMOD_PATTERN_ADDRESS  = RAM_START     ;(word)
PSGMOD_SONG_START       = RAM_START + 2 ;(word)
PSGMOD_SONG_POSITION    = RAM_START + 4 ;(byte)
PSGMOD_PATTERN_POSITION = RAM_START + 5 ;(byte)
PSGMOD_CURRENT_SPEED    = RAM_START + 6 ;(byte)
PSGMOD_SPEED_COUNTER    = RAM_START + 7 ;(byte)
PSGMOD_SOUND_DISABLED   = RAM_START + 8 ;(byte)

;=============================================================================
; Misc variables
;=============================================================================
VBLANK_COUNTER          = RAM_START + 9  ;(byte)
PREVIOUS_CONTROL_STATUS = RAM_START + 10 ;(byte)



;=============================================================================
; Start code
;=============================================================================
.org $0000
  di
  im 1
  ld sp, $dff0
  jr START

;=============================================================================
; IRQ handler
;=============================================================================
.org $0038
  exx
  ex af, af'
  in a, ($BF)

  ld hl, VBLANK_COUNTER
  inc (HL)

  exx
  ex af, af'
  ei
  reti

;=============================================================================
; NMI handler
;=============================================================================
.org $0066
  retn



START:
  call SETUP_FRAMES
  call SET_VDP_REGS_TABLE

; Set Game Gear stereo sound mask
  ld a, 195
  out (GAME_GEAR_STEREO_SOUND_PORT), a

;=============================================================================
; Song start
;=============================================================================
    ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG
  ei
SONG_LOOP:
    ld d, 1                       ; wait one VBlank
  call VWAIT

  call PSGMOD_PLAY_NEXT_NOTE      ; play next note

  in a, (CONTROL_PORT)            ; get control status
  ld b, a                         ; save it to b
  ld a, (PREVIOUS_CONTROL_STATUS) ; button already pressed before?
  bit 4, a
  jr Z, BUTTON_NOT_PRESSED_AGAIN  ; jump away if yes
  ld a, b                         ; button now pressed?
  bit 4, a
  jr NZ, BUTTON_NOT_PRESSED_AGAIN ; jump away if not
  call PSGMOD_TOGGLE_SOUND        ; toggle sound on or off
BUTTON_NOT_PRESSED_AGAIN:
  ld a, b                         ; get control status from b
  ld (PREVIOUS_CONTROL_STATUS), a ; save control status to previous
                                  ; control status

  jr SONG_LOOP
;=============================================================================
; Program end
;=============================================================================

.include PSGMOD.INC



VWAIT:
  ld a, 0
  ld (VBLANK_COUNTER), a
VWAIT_LOOP:
  ld a, (VBLANK_COUNTER)
  cp d
  ret Z
  jr VWAIT_LOOP

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

SET_VDP_REGS_TABLE:
  ld hl, VDP_REGS_TABLE
  ld b, $0f
  ld c, $80
VDP_REGS_LOOP:
  ld a, (HL)
  inc hl
  out ($bf), a
  ld a, c
  inc c
  out ($bf), a
  dec b
  jr NZ, VDP_REGS_LOOP
  ret

VDP_REGS_TABLE:
   .db $06, $60, $FF, $FF, $FF, $FF, $00, $00, $00, $00, $FF, $00, $00, $00, $00, $00

PSGMOD_SONG:
.db 0,1,2,3,4,5,6,7
.db 8,9,10,11,12,13,14,5
.db 15,16,17,18,19,20,21,22
.db 23,18,19,20,21,22,23,24
.db 25,26,27,28,29,26,27,28
.db 29,30,128,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0

; Pattern 0:
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,15,1807,3971,7494,15,1807,
.dw 3971,7494,1872,1551,3971,7494,2496,1551,
.dw 3971,7494,3136,1551,3971,7494,3328,1807,
.dw 3971,7494,3328,1807,3971,7494,3328,1807,
.dw 3971,7494,3328,2319,3971,7494,3328,2319,
.dw 3971,7494,4208,1551,3971,7494,4208,1551,
.dw 3971,7494,4208,1807,3971,7494,4208,1807,
.dw 3971,7494,3744,1551,3971,7494,3744,1551,
.dw 3971,7494,3744,1295,3971,7494,3744,1295,
.dw 3971,7494,3328,1551,3971,7494,3328,1551,
.dw 3971,7494,3328,1551,3971,7494,3328,1551,
.dw 3971,7494,4208,1551,3971,7494,4208,1551,
.dw 3971,7494,4208,1295,3971,7494,4208,1295,
.dw 3971,7494,3744,1551,3971,7494,3744,1551,
.dw 3971,7494,3744,1807,3971,7494,3744,1807,
.dw 3971,7494,4992,5391,3971,7494,4992,5391,
.dw 3971,7494,4992,5391,3971,7494,3141,5391,
; Pattern 1:
.dw 15,6294,2805,2831,15,6294,2805,2831,
.dw 15,6294,2498,2633,15,6294,2498,2575,
.dw 15,6294,2496,2636,15,6294,2496,1609,
.dw 15,6294,2498,1551,15,6294,2503,2598,
.dw 15,6294,2511,2575,15,6294,2511,3142,
.dw 15,6294,2511,3087,15,6294,2511,2633,
.dw 15,6294,2511,2575,15,6294,2511,2633,
.dw 15,6294,2511,1606,15,6294,2511,1551,
.dw 15,5606,8421,2630,15,5606,8421,2575,
.dw 15,5606,8421,2633,15,5606,8421,2575,
.dw 15,5606,8421,2636,15,5606,8933,2575,
.dw 15,5606,8933,2575,15,5606,8933,2575,
.dw 15,5606,8933,2575,15,5606,8933,2575,
.dw 15,5606,8933,2575,15,5606,8933,2575,
.dw 15,5606,8933,2575,15,5606,8933,2575,
.dw 15,5606,8933,2575,15,5606,8933,2575,
.dw 15,6294,8933,2634,15,6294,8933,2575,
.dw 15,6294,8421,2575,15,6294,8421,2575,
.dw 15,6294,8421,2575,15,6294,8421,2575,
.dw 15,6294,8421,2575,15,6294,8421,2575,
.dw 15,6294,8421,2575,15,6294,7493,2575,
.dw 15,6294,7493,2575,15,6294,7493,2575,
.dw 15,6294,7493,2575,15,6294,7493,2575,
.dw 15,6678,6677,2634,15,6678,6677,2575,
.dw 15,6678,6293,2575,15,6678,6293,2575,
.dw 15,6678,6293,2575,15,6678,6293,2575,
.dw 15,6678,5605,2575,15,6678,5605,2575,
.dw 15,8418,5605,2634,15,8418,5605,2575,
.dw 15,8418,4997,2575,15,8418,4997,2575,
.dw 15,8418,4997,2575,15,8418,4997,2575,
.dw 15,8418,4213,2575,15,8418,4213,2575,
.dw 15,8418,4213,2575,15,8418,4213,2575,
; Pattern 2:
.dw 4721,1876,15,1089,15,1876,15,1039,
.dw 1886,3748,15,1103,15,3748,15,1039,
.dw 1872,3140,15,1089,15,3140,15,1103,
.dw 1872,3748,15,1089,15,3748,15,1071,
.dw 15,2500,15,1039,15,2500,15,1103,
.dw 1882,3140,15,1039,15,3140,15,1103,
.dw 1872,3748,15,1039,15,3748,15,1103,
.dw 1872,6292,15,1103,15,6292,15,1039,
.dw 15,8420,15,1103,15,8420,15,1039,
.dw 1882,4212,15,1103,15,4212,15,1039,
.dw 2096,3332,15,1090,15,3332,15,1039,
.dw 2096,5604,15,1090,15,5604,15,1039,
.dw 4721,7492,15,1090,15,7492,15,1039,
.dw 2106,3748,15,1039,1886,3748,15,1039,
.dw 1872,3140,15,1090,15,3140,15,1039,
.dw 1872,3748,15,1090,15,3748,15,1039,
.dw 15,2500,15,1103,15,2500,15,1039,
.dw 1882,3140,15,1039,15,3140,15,1039,
.dw 1872,3748,15,1039,15,3748,15,1039,
.dw 1872,6292,15,1039,15,6292,15,1039,
.dw 15,8420,15,1090,15,8420,15,1039,
.dw 1882,4212,15,1039,15,4212,15,1039,
.dw 2096,3332,15,1090,15,3332,15,1039,
.dw 2096,4212,15,1090,15,4212,15,33807,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1103,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
.dw 15,4217,15,1039,15,4217,15,1039,
; Pattern 3:
.dw 15,7492,15,1089,15,7492,15,1039,
.dw 2106,3748,15,1089,15,3748,15,1039,
.dw 1872,3140,15,1103,15,3140,15,1103,
.dw 1872,3748,15,1103,15,3748,15,1071,
.dw 15,4996,3744,1039,15,4996,3744,1103,
.dw 1882,3140,3749,1039,15,3140,3749,1103,
.dw 1872,3748,3744,1039,15,3748,3744,1103,
.dw 1872,6292,3136,1103,15,6292,3136,1039,
.dw 15,8420,3328,1103,15,8420,3333,1039,
.dw 1882,4212,3744,1103,15,4212,3744,1039,
.dw 2096,3332,4208,1090,15,3332,4208,1039,
.dw 2096,5604,4213,1090,15,5604,4213,1039,
.dw 15,9460,3744,1089,15,9460,3744,1039,
.dw 2106,3748,3744,1039,15,3748,3744,1039,
.dw 2352,3140,3744,1089,15,3140,3744,1039,
.dw 2352,2356,3744,1089,15,2356,3744,1039,
.dw 2498,2361,3746,1089,2510,2367,3749,1039,
.dw 2510,2356,3754,1039,2510,2356,3754,1039,
.dw 3138,6292,4208,1089,3150,6292,4208,1039,
.dw 3150,6293,4213,1089,3150,6292,4213,1039,
.dw 3138,6297,4208,1103,3150,6303,4208,1039,
.dw 3150,6292,4720,1039,3150,6292,4725,1039,
.dw 3138,6293,4992,1103,3150,6292,4992,1039,
.dw 2498,6293,4208,1103,2510,6292,4208,1039,
.dw 2802,6297,4720,1039,2814,6303,4720,1039,
.dw 2814,6303,4725,1039,2814,6303,4725,1039,
.dw 2802,5604,4720,1090,2814,5604,4720,1039,
.dw 2814,5605,4725,1090,2814,5604,4725,1039,
.dw 3138,5609,4992,1090,3150,5615,4992,1039,
.dw 3151,5615,4992,1039,3151,5615,4992,1039,
.dw 3151,6292,4992,1090,3151,6292,4992,1039,
.dw 3151,6293,4992,1090,3151,6292,4992,1039,
; Pattern 4:
.dw 15,7492,15,1089,15,7492,15,1039,
.dw 1882,3748,15,1103,15,3748,15,1039,
.dw 1872,3140,3744,1103,15,3140,3744,1103,
.dw 1872,3748,3749,1103,15,3748,3749,1071,
.dw 15,4996,3744,1039,15,4996,3744,1103,
.dw 1882,3140,3744,1039,15,3140,3744,1103,
.dw 1872,3748,3745,1039,15,3748,3744,1103,
.dw 1872,6292,3136,1103,15,6292,3136,1039,
.dw 15,8420,3328,1089,15,8420,3333,1039,
.dw 1882,4212,3744,1103,15,4212,3744,1039,
.dw 2096,3332,4208,1089,15,3332,4208,1039,
.dw 2096,5604,4213,1089,15,5604,4213,1039,
.dw 15,9460,3744,1089,15,9460,3744,1039,
.dw 2106,3748,3744,1039,15,3748,3744,1039,
.dw 2352,3140,3744,1089,15,3140,3744,1039,
.dw 2352,2356,3744,1089,15,2356,3744,1039,
.dw 2498,2361,3744,1103,2510,2367,3744,1039,
.dw 2510,2356,3746,1039,2510,2356,3749,1039,
.dw 3138,6292,3754,1103,3150,6292,3754,1039,
.dw 3150,6293,3328,1103,3150,6292,3328,1039,
.dw 3138,6297,3136,1089,3150,6303,3136,1039,
.dw 3150,6292,3141,1089,3150,6292,3141,1039,
.dw 3150,4996,3136,1103,3150,4996,3136,1039,
.dw 2498,4997,3136,1089,2510,4996,3136,1039,
.dw 2802,5001,2800,1089,2814,5007,2800,1039,
.dw 2814,5007,2800,1039,2814,5007,2800,1039,
.dw 2802,5604,2800,1089,2814,5604,2800,1039,
.dw 2814,5605,2800,1089,2814,5604,2800,1039,
.dw 4210,5609,3328,1089,4222,5615,3328,1039,
.dw 4223,2096,3328,1089,4223,2805,3328,1039,
.dw 2096,2096,3328,1103,15,2805,3328,1039,
.dw 2096,2096,3136,1103,15,2805,3136,1039,
; Pattern 5:
.dw 15,15,3328,1103,15,15,3333,1039,
.dw 15,15,3744,1103,15,15,3749,1039,
.dw 2096,2096,4208,1103,15,2099,4208,1103,
.dw 2096,2111,3328,1103,15,2111,3328,33839,
.dw 15,2111,3328,1039,15,2111,3328,1103,
.dw 15,2111,3328,1039,15,2111,3328,1103,
.dw 15,2111,3328,1039,15,2111,3328,1103,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1039,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 2096,2111,4208,1103,15,2111,4208,1039,
.dw 2096,2111,3328,1039,15,2111,3328,33807,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1039,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
.dw 15,2111,3328,1103,15,2111,3328,1039,
; Pattern 6:
.dw 15,2501,3136,1089,15,2504,3136,1039,
.dw 15,2501,3141,1089,15,2504,3141,1039,
.dw 1568,2501,3136,1103,15,2504,3136,1103,
.dw 1568,2505,3136,1089,15,15,3136,1071,
.dw 15,1989,3328,1089,15,1992,3328,1103,
.dw 1578,1989,3328,1039,15,1989,3328,1103,
.dw 2496,2501,3329,1089,15,2504,3328,1103,
.dw 2496,1989,3333,1089,15,1992,3333,1039,
.dw 15,1877,3744,1089,15,1880,3744,1039,
.dw 2506,1877,3744,1089,15,1880,3744,1039,
.dw 1872,1877,3744,1103,15,1880,3744,1039,
.dw 1872,1877,3136,1103,15,1877,3136,1039,
.dw 15,2101,3328,1103,15,2104,3333,1039,
.dw 1882,2101,3744,1039,15,2104,3744,1039,
.dw 2096,2101,4208,1103,15,2104,4208,1039,
.dw 2096,15,3328,1103,15,15,3328,1039,
.dw 15,15,3136,1089,15,15,3136,1039,
.dw 2106,15,3141,1089,15,15,3141,1039,
.dw 1568,2501,3136,1103,15,2501,3136,1039,
.dw 1568,2502,3136,1089,15,2501,3136,1039,
.dw 15,2502,3328,1089,15,2504,3328,1039,
.dw 1578,2501,3328,1103,15,2504,3328,1039,
.dw 2496,2357,3329,1089,15,2360,3328,1039,
.dw 2496,1989,3333,1089,15,1992,3333,1039,
.dw 15,1877,3744,1089,15,1880,3744,1039,
.dw 2506,1877,3744,1089,15,1880,3744,1039,
.dw 1872,1877,3744,1103,15,1880,3744,1039,
.dw 1872,15,3136,1103,15,15,3136,1039,
.dw 15,2101,3328,1103,15,2104,3328,1039,
.dw 1882,2101,3744,1103,15,2104,3749,1039,
.dw 2096,2101,4208,1103,15,2104,4208,1039,
.dw 2096,15,4208,1103,15,15,4208,1039,
; Pattern 7:
.dw 15,2357,3744,1089,15,2360,3744,1039,
.dw 15,2357,3749,1089,15,2360,3749,1039,
.dw 2352,2357,3744,1103,15,2357,3744,1103,
.dw 2352,2357,3744,1089,15,2357,3744,1071,
.dw 15,2358,3745,1089,15,2360,3744,1103,
.dw 2362,2357,3744,1039,15,2360,3744,1103,
.dw 2352,2357,3744,1103,15,2357,3744,1103,
.dw 2352,2357,3744,1103,15,2357,3744,1039,
.dw 2498,2357,3744,1103,2510,2357,3746,1039,
.dw 2511,2357,3749,1103,2511,2357,3754,1039,
.dw 3138,6293,3744,1103,3150,6293,3744,1039,
.dw 3151,6294,3744,1103,3151,6293,3744,1039,
.dw 3138,6298,4208,1089,3150,6298,4208,1039,
.dw 3151,6303,4720,1089,3151,6303,4725,1039,
.dw 3151,4997,4992,1103,3151,4997,4992,1039,
.dw 2498,4998,4208,1089,2510,4997,4208,1039,
.dw 2802,5002,4720,1089,2814,5002,4720,1039,
.dw 2815,5007,4725,1103,2815,5007,4725,1039,
.dw 2802,5605,4720,1089,2814,5605,4720,1039,
.dw 2815,5606,4720,1089,2815,5605,4720,33807,
.dw 2498,5615,4992,1089,2510,5615,4992,1039,
.dw 2511,5615,4992,1103,2511,5615,4992,1039,
.dw 2511,5615,4992,1103,2511,5615,4992,1039,
.dw 2511,5615,4994,1103,2511,5615,4997,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,33807,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
.dw 2511,5615,5002,1103,2511,5615,5002,1039,
; Pattern 8:
.dw 2498,7492,4992,1089,2510,7492,4992,1039,
.dw 2511,3748,4992,1103,2511,3748,4992,1039,
.dw 1872,3140,4994,1089,15,3140,4997,1103,
.dw 1872,3748,5002,1089,15,3748,5006,1071,
.dw 15,2500,5006,1103,15,2500,5006,1103,
.dw 15,3140,5006,1039,15,3140,5006,1103,
.dw 1872,3748,5006,1103,15,3748,5006,1103,
.dw 1872,6292,5006,1103,15,6292,5006,1039,
.dw 15,8420,5006,1103,15,8420,5006,1039,
.dw 15,4212,5006,1103,15,4212,5006,1039,
.dw 2096,3332,5006,1090,15,3332,5006,1039,
.dw 2096,5604,5006,1090,15,5604,5006,1039,
.dw 15,7492,5006,1090,15,7492,5006,1039,
.dw 15,3748,5006,1103,15,3748,5006,1039,
.dw 1872,3140,5006,1090,15,3140,5006,1039,
.dw 1872,3748,5006,1090,15,3748,5006,1039,
.dw 15,4996,5006,1103,15,4996,5006,1039,
.dw 15,3140,5006,1103,15,3140,5006,1039,
.dw 1872,3748,5006,1103,15,3748,5006,1039,
.dw 1872,6292,5006,1103,15,6292,5006,1039,
.dw 15,8420,4992,1090,15,8420,4992,1039,
.dw 15,4212,4992,1103,15,4212,4992,1039,
.dw 2096,3332,4208,1090,15,3332,4208,1039,
.dw 2096,4212,4213,1090,15,4212,4213,33807,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
.dw 15,4217,4213,1103,15,4217,4213,1039,
; Pattern 9:
.dw 2498,15,3744,1089,2510,15,3744,1039,
.dw 4722,15,3744,1103,4734,15,3744,1039,
.dw 3138,3141,3136,1089,3150,3141,3136,1103,
.dw 4722,3142,3141,1089,4734,3141,3141,1071,
.dw 3138,3146,3136,1103,3150,3146,3136,1103,
.dw 4994,3146,3136,1039,5006,3146,3136,1103,
.dw 3746,3141,3136,1103,3758,3141,3136,1103,
.dw 4994,3142,3136,1103,5006,3141,3136,1039,
.dw 3746,3146,4720,1103,3758,3146,4720,1039,
.dw 4994,3146,2496,1103,5006,3146,2501,1039,
.dw 4210,3141,2800,1103,4222,3141,2805,1039,
.dw 4994,3142,2352,1103,5006,3141,2352,1039,
.dw 2498,3146,4208,1103,2510,3146,4208,1039,
.dw 4994,3146,4208,1103,5006,3146,4208,1039,
.dw 4210,4213,3136,1089,4222,4213,3136,1039,
.dw 4994,4214,3141,1089,5006,4213,3141,1039,
.dw 3138,4218,3136,1089,3150,4218,3136,1039,
.dw 4994,4218,3136,1103,5006,4218,3136,1039,
.dw 4210,4213,3136,1089,4222,4213,3136,1039,
.dw 4994,4214,3136,1103,5006,4213,3136,1039,
.dw 3138,4218,4992,1103,3150,4218,4992,1039,
.dw 4994,4218,4992,1103,5006,4218,4992,1039,
.dw 4210,4213,3136,1103,4222,4213,3136,1039,
.dw 4994,4214,3136,1103,5006,4213,3136,33807,
.dw 3138,4218,3136,1103,3150,4218,3136,1039,
.dw 4994,4223,3136,1103,5006,4223,3136,1039,
.dw 3746,4223,3136,1103,3758,4223,3136,1039,
.dw 4994,4223,3136,1103,5006,4223,3136,1039,
.dw 2498,4223,3136,1103,2510,4223,3136,1039,
.dw 4994,4223,3136,1103,5006,4223,3136,1039,
.dw 3138,4223,3136,1103,3150,4223,3136,1039,
.dw 4994,4223,3136,1103,5006,4223,3136,1039,
; Pattern 10:
.dw 3138,15,4720,1089,3150,15,4720,1039,
.dw 4994,15,4720,1103,5006,15,4720,1039,
.dw 3746,2357,4208,1089,3758,2357,4208,1103,
.dw 4994,2358,4213,1089,5006,2357,4213,1071,
.dw 2498,2357,4208,1089,2510,2357,4208,1103,
.dw 4994,2357,4208,1039,5006,2357,4208,1103,
.dw 3138,2358,4208,1089,3150,2357,4208,1103,
.dw 3746,2358,2800,1103,3758,2357,2800,1039,
.dw 3138,2357,4208,1089,3150,2357,4208,1039,
.dw 3330,2357,2800,1103,3342,2357,2805,1039,
.dw 3746,2358,3136,1103,3758,2357,3146,1039,
.dw 3330,2358,2800,1103,3342,2357,2810,1039,
.dw 3138,2357,3136,1089,3150,2357,3146,1039,
.dw 4994,2357,3146,1089,5006,2357,3146,1039,
.dw 3746,3749,3328,1089,3758,3749,3338,1039,
.dw 4994,3750,3338,1103,5006,3749,3338,1039,
.dw 3746,3749,3744,1089,3758,3749,3744,1039,
.dw 4994,3749,3744,1103,5006,3749,3744,1039,
.dw 3746,3750,4992,1089,3758,3749,4992,1039,
.dw 4994,3750,5002,1103,5006,3749,5002,1039,
.dw 3746,3749,4992,1089,3758,3749,4992,1039,
.dw 4994,3749,4992,1103,5006,3749,4992,1039,
.dw 3746,3750,4992,1103,3758,3749,4992,1039,
.dw 4994,3750,4992,1103,5006,3749,4992,1039,
.dw 3746,3749,6672,1103,3758,3749,6672,1039,
.dw 4994,3749,6672,1103,5006,3749,6672,1039,
.dw 3746,3750,6288,1089,3758,3749,6288,1039,
.dw 4994,3750,6293,1089,5006,3749,6293,33807,
.dw 5006,3749,6293,1103,5006,3749,6293,1039,
.dw 5006,3749,6293,1103,5006,3749,6293,1039,
.dw 5006,3750,6293,1103,5006,3749,6293,1039,
.dw 5006,3750,6293,1103,5006,3749,6293,1039,
; Pattern 11:
.dw 3536,15,2812,1089,15,15,2812,1039,
.dw 15,3541,2812,1103,15,3541,2812,1039,
.dw 1760,1765,2812,1089,15,1765,2812,1103,
.dw 1760,2357,2812,1103,15,2357,2812,1071,
.dw 15,2358,2812,1089,15,2357,2812,1103,
.dw 15,2805,2812,1039,15,2805,2812,1103,
.dw 15,1765,2812,1103,15,1765,2812,1103,
.dw 15,1397,2812,1103,15,1397,2812,1039,
.dw 15,3541,2812,1103,15,3541,2812,1039,
.dw 15,2805,2812,1103,15,2805,2812,1039,
.dw 1760,1765,2812,1103,15,1765,2812,1039,
.dw 1760,3541,2812,1103,15,3541,2812,1039,
.dw 15,2357,2812,1103,15,2357,2812,1039,
.dw 15,2358,2812,1103,15,2357,2812,1039,
.dw 15,1397,2812,1089,15,1397,2812,1039,
.dw 15,1765,2812,1089,15,1765,2812,1039,
.dw 1250,1770,3148,1089,1262,1775,3148,1039,
.dw 1263,1775,3148,1103,1263,1775,3148,1039,
.dw 1570,3141,3148,1089,1582,3141,3148,1039,
.dw 1583,3142,3148,1103,1583,3141,3148,1039,
.dw 1570,3141,3148,1089,1582,3141,3148,1039,
.dw 1583,3141,3148,1103,1583,3141,3148,1039,
.dw 1583,3142,3148,1103,1583,3141,3148,1039,
.dw 1570,3142,3148,1103,1582,3141,3148,1039,
.dw 1666,3141,3148,1103,1678,3141,3148,1039,
.dw 1679,3141,3148,1103,1679,3141,3148,1039,
.dw 1570,3142,3148,1103,1582,3141,3148,1039,
.dw 1583,3142,3148,1103,1583,3141,3148,1039,
.dw 1666,3141,3148,1089,1678,3141,3148,1089,
.dw 1570,3141,3148,1089,1582,3141,3148,1039,
.dw 1874,3142,3758,1089,1886,3141,3758,1039,
.dw 1570,3142,3758,1089,1582,3141,3758,1039,
; Pattern 12:
.dw 15,15,3148,1089,15,15,3148,1039,
.dw 15,4725,3148,1103,15,4725,3148,1039,
.dw 2352,2357,3148,1089,15,2357,3148,1103,
.dw 2352,3141,3148,1103,15,3141,3148,1071,
.dw 15,1573,3148,1089,15,1573,3148,1103,
.dw 15,3973,3148,1039,15,3973,3148,1103,
.dw 2352,2101,3148,1103,15,2101,3148,1103,
.dw 2352,1989,3148,1103,15,1989,3148,1039,
.dw 15,4725,2364,1103,15,4725,2364,1039,
.dw 15,3141,2364,1103,15,3141,2364,1039,
.dw 2352,2357,2364,1103,15,2357,2364,1039,
.dw 2352,3973,2364,1103,15,3973,2364,1039,
.dw 15,1573,2364,1103,15,1573,2364,1039,
.dw 15,3141,2364,1103,15,3141,2364,1039,
.dw 2352,1989,2364,1089,15,1989,2364,1039,
.dw 15,2357,2364,1089,15,2357,2364,1039,
.dw 1394,2362,2108,1089,1406,2367,2108,1039,
.dw 1407,2367,2108,1103,1407,2367,2108,1039,
.dw 1666,4213,2108,1089,1678,4213,2108,1039,
.dw 1679,4214,2108,1103,1679,4213,2108,1039,
.dw 1666,4218,2108,1089,1678,4223,2108,1039,
.dw 1679,4223,2108,1103,1679,4223,2108,1039,
.dw 1679,4213,2108,1103,1679,4213,2108,1039,
.dw 1666,4214,2108,1103,1678,4213,2108,1039,
.dw 1874,4218,2108,1103,1886,4223,2108,1039,
.dw 1887,4223,2108,1103,1887,4223,2108,1039,
.dw 1666,4213,2108,1103,1678,4213,2108,1039,
.dw 1679,4214,2108,1103,1679,4213,2108,1039,
.dw 1874,4218,2108,1103,1886,4223,2109,1103,
.dw 1666,4223,2110,1103,1678,4223,2111,1039,
.dw 2098,4213,2111,1089,2110,4213,2111,1039,
.dw 2111,4214,2111,1089,2111,4213,2111,1039,
; Pattern 13:
.dw 1874,4726,3744,1089,1886,15,3744,1039,
.dw 1887,15,3749,1103,1887,15,3749,1039,
.dw 1872,6293,3744,1089,15,6293,3744,1103,
.dw 1872,3141,3136,1089,15,3141,3136,1071,
.dw 15,4213,3328,1103,15,4213,3333,1103,
.dw 15,5605,3744,1039,15,5605,3744,1103,
.dw 2096,6677,4208,1089,15,6677,4208,1103,
.dw 2096,3333,4208,1089,15,3333,4208,1039,
.dw 15,3141,3744,1089,15,3141,3744,1039,
.dw 15,6293,3744,1089,15,6293,3744,1039,
.dw 2352,3141,3744,1103,15,3141,3744,1039,
.dw 2352,3146,3744,1089,15,3151,3744,1039,
.dw 2498,3151,3746,1089,2510,3151,3748,1039,
.dw 4210,3151,3754,1103,4222,3151,3754,1039,
.dw 3138,3141,4208,1089,3150,3141,4208,1039,
.dw 4210,3142,4213,1089,4222,3141,4213,1039,
.dw 3138,3146,4208,1103,3150,3151,4208,1039,
.dw 4210,3151,4720,1103,4222,3151,4720,1039,
.dw 3138,3141,4992,1103,3150,3141,4994,1039,
.dw 2498,3142,4208,1103,2510,3141,4213,1039,
.dw 2802,3146,4720,1089,2814,3146,4720,1039,
.dw 4722,3146,4725,1089,4734,3146,4725,1039,
.dw 2802,2805,4720,1103,2814,2805,4720,1039,
.dw 4722,2806,4725,1089,4734,2805,4725,1039,
.dw 3138,2810,4992,1089,3150,2810,4992,1039,
.dw 4994,2810,4992,1103,5006,2810,4992,1039,
.dw 3746,3141,4992,1089,3758,3141,4992,1039,
.dw 4994,3142,4992,1089,5006,3141,4992,1039,
.dw 5006,3146,4994,1103,5006,3146,4997,1103,
.dw 5006,3146,5002,1103,5006,3146,5002,33807,
.dw 5006,3146,5002,1103,5006,3146,5002,1039,
.dw 5006,3146,5002,1103,5006,3146,5002,1039,
; Pattern 14:
.dw 1872,6293,3744,1103,15,6293,3744,1039,
.dw 1872,3141,3749,1103,15,3141,3749,1039,
.dw 15,3749,3744,1103,15,3749,3744,1103,
.dw 1882,4997,3744,1103,15,4997,3744,1071,
.dw 1872,3749,3744,1089,15,3749,3744,1103,
.dw 1872,3750,3136,1089,15,3749,3136,1103,
.dw 15,4213,3328,1089,15,4213,3333,1103,
.dw 1882,2805,3744,1089,15,2805,3744,1039,
.dw 2096,3749,4208,1103,15,3749,4208,1039,
.dw 2096,2501,4208,1089,15,2501,4208,1039,
.dw 15,2357,3744,1089,15,2357,3744,1039,
.dw 2106,3141,3744,1103,15,3141,3744,1039,
.dw 2352,3749,3744,1089,15,3749,3744,1039,
.dw 2352,3754,3744,1089,15,3754,3744,1039,
.dw 2354,3759,3744,1103,2366,3759,3744,1039,
.dw 3138,3759,3744,1103,3150,3759,3746,1039,
.dw 2354,4725,3749,1103,2366,4725,3754,1039,
.dw 2098,4726,3328,1103,2110,4725,3328,1039,
.dw 2498,4730,3136,1089,2510,4730,3136,1039,
.dw 3138,4730,3141,1089,3150,4730,3141,1039,
.dw 2498,4997,3136,1103,2510,4997,3136,1039,
.dw 3138,4998,3136,1089,3150,4997,3136,1039,
.dw 2354,5002,2800,1089,2366,5002,2800,1039,
.dw 2802,5002,2800,1103,2814,5002,2800,1039,
.dw 2354,4725,2800,1089,2366,4725,2800,1039,
.dw 2802,4726,2800,1089,2814,4725,2800,1039,
.dw 2098,2805,3328,1089,2110,2810,3328,1039,
.dw 3330,2805,3328,1089,3342,2810,3328,1039,
.dw 2802,2805,3328,1103,2814,2810,3328,1103,
.dw 2814,2805,3136,1103,2814,2810,3136,1039,
.dw 2814,2805,3328,1103,2814,2805,3333,1039,
.dw 2814,2805,3744,1103,2814,2805,3744,33807,
; Pattern 15:
.dw 15,2501,3136,1089,15,2504,3136,1039,
.dw 15,2501,3136,1089,15,2504,3136,1039,
.dw 1568,2501,3137,1103,15,2504,3136,1103,
.dw 1568,2505,3136,1089,15,15,3136,1071,
.dw 15,1989,3328,1089,15,1992,3328,1103,
.dw 15,1989,3328,1103,15,1992,3328,1103,
.dw 2496,1989,3328,1089,15,1992,3328,1103,
.dw 2496,1993,3328,1089,15,15,3328,1039,
.dw 15,1877,3744,1089,15,1880,3744,1039,
.dw 15,1877,3744,1089,15,1880,3744,1039,
.dw 1872,1877,3744,1103,15,1880,3744,1039,
.dw 1872,1877,3136,1103,15,1877,3136,1039,
.dw 15,1877,3328,1103,15,1877,3333,1039,
.dw 15,1877,3744,1103,15,1877,3744,1039,
.dw 2096,2101,4208,1103,15,2104,4208,1039,
.dw 2096,2101,3328,1103,15,2104,3338,1039,
.dw 15,2501,3136,1089,15,2504,3136,1039,
.dw 15,2501,3141,1089,15,2504,3141,1039,
.dw 1568,2501,3136,1103,15,2504,3136,1039,
.dw 1568,2505,3141,1089,15,15,3141,1039,
.dw 15,1992,3328,1089,15,1989,3328,1039,
.dw 15,1992,3328,1103,15,1989,3328,1039,
.dw 1248,1992,3329,1089,15,1993,3328,1039,
.dw 1248,15,3328,1089,15,15,3328,1039,
.dw 15,1877,3744,1089,15,1880,3744,1039,
.dw 15,1877,3744,1089,15,1880,3744,1039,
.dw 1872,1877,3744,1103,15,1880,3744,1039,
.dw 1872,1877,3136,1103,15,1877,3136,1039,
.dw 15,1877,3328,1103,15,1877,3328,1103,
.dw 15,1877,3744,1103,15,1877,3749,1039,
.dw 2096,2101,4208,1103,15,2104,4208,1039,
.dw 2096,2101,4208,1103,15,2104,4208,1039,
; Pattern 16:
.dw 15,2357,3744,1089,15,2360,3744,1039,
.dw 15,2357,3749,1089,15,2360,3749,1039,
.dw 2352,2357,3744,1103,15,2360,3744,1103,
.dw 2352,2357,3749,1089,15,2360,3749,1071,
.dw 1874,1769,3744,1089,1886,15,3744,1103,
.dw 1887,15,3744,1103,1887,15,3744,1103,
.dw 2098,15,3744,1103,2110,15,3744,1103,
.dw 2354,15,3744,1103,2366,15,3744,1039,
.dw 2498,3141,3744,1089,2510,3141,3745,1039,
.dw 2511,3141,3746,1089,2511,3141,3748,1039,
.dw 3138,3142,4208,1103,3150,3141,4208,1039,
.dw 4210,3142,4213,1089,4222,3141,4213,1039,
.dw 2802,3141,4720,1089,2814,3141,4720,1039,
.dw 4210,3141,4992,1103,4222,3141,4992,1039,
.dw 2802,2805,4720,1089,2814,2805,4720,1039,
.dw 3746,2806,4725,1089,3758,2805,4725,1039,
.dw 3138,2805,4992,1089,3150,2805,4992,1039,
.dw 3151,7493,4992,1103,3151,7493,4992,1039,
.dw 1872,4213,4992,1089,15,4213,4992,1039,
.dw 1872,3749,4992,1089,15,3749,4992,1039,
.dw 15,3333,4994,1103,15,3333,4997,1039,
.dw 15,7493,5002,1103,15,7493,5006,1039,
.dw 1872,5605,3744,1103,15,5605,3744,1039,
.dw 1872,2805,3749,1103,15,2805,3749,1039,
.dw 15,2501,3744,1103,15,2504,3744,1039,
.dw 15,2501,3746,1103,15,2504,3746,1039,
.dw 1872,2501,3746,1103,15,2504,3746,1039,
.dw 1872,2501,3136,1103,15,2504,3136,1039,
.dw 15,2499,3328,1103,15,15,3328,1103,
.dw 15,2803,3744,1103,15,15,3744,1039,
.dw 2096,15,4208,1089,15,15,4208,1039,
.dw 2096,3139,4208,1089,15,15,4208,1039,
; Pattern 17:
.dw 15,3141,3744,1089,15,3144,3744,1039,
.dw 15,3141,3749,1089,15,3144,3749,1039,
.dw 2352,3141,3744,1103,15,3144,3744,1103,
.dw 2352,3141,3749,1089,15,3144,3749,1071,
.dw 3138,3145,3744,1089,3150,15,3744,1103,
.dw 3746,15,3744,1103,3758,15,3744,1103,
.dw 2498,15,3744,1103,2510,15,3745,1103,
.dw 3138,15,3136,1103,3150,15,3136,1039,
.dw 2098,15,2800,1089,2110,15,2800,1039,
.dw 2802,15,3136,1089,2814,15,3141,1039,
.dw 4210,5605,3328,1103,4222,5605,3328,1039,
.dw 3330,5606,2800,1089,3342,5605,2800,1039,
.dw 3746,5605,3136,1089,3758,5605,3136,1039,
.dw 3138,5609,3744,1103,3150,5614,3749,1039,
.dw 3330,5615,3328,1089,3342,5615,3328,1039,
.dw 3343,5615,3328,1089,3343,5615,3328,1039,
.dw 3746,5615,3744,1089,3758,5615,3744,1039,
.dw 3759,5615,3744,1103,3759,5615,3744,1039,
.dw 3759,5615,3744,1103,3759,5615,3744,1039,
.dw 3759,5615,3744,1103,3759,5615,3745,1039,
.dw 3759,5615,3748,1103,3759,5615,3752,1039,
.dw 3759,5615,3757,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1103,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
.dw 3759,5615,3759,1103,3759,5615,3759,1039,
; Pattern 18:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 15,3136,3141,1089,15,3136,3150,1103,
.dw 4721,3137,4213,1103,15,3136,4222,1071,
.dw 15,2640,4223,1090,15,2640,4223,1103,
.dw 15,2640,6293,1103,15,2640,6302,1103,
.dw 4721,2096,3141,1103,15,2096,3150,1103,
.dw 15,2096,4213,1103,15,2096,4222,1039,
.dw 15,2224,4223,1103,15,2224,4223,1039,
.dw 15,2224,5605,1103,15,2224,5614,1039,
.dw 4721,2225,2805,1089,15,2224,2814,1039,
.dw 4721,2224,3749,1103,15,2224,3758,1039,
.dw 3141,2800,3759,1103,3141,2800,3759,1039,
.dw 3141,2800,5605,1103,3141,2800,5614,1039,
.dw 4721,2800,2805,1089,15,2800,2814,1039,
.dw 15,2800,3749,1103,15,2800,3758,1039,
.dw 3141,3968,3759,1103,3141,3968,3759,1039,
.dw 3141,3968,6293,1103,3141,3968,6302,1039,
.dw 4721,3969,3141,1089,15,3968,3150,1039,
.dw 3141,3968,3973,1103,3141,3968,3982,1039,
.dw 3141,3969,3982,1089,3141,3968,3982,1039,
.dw 3141,3968,6293,1103,3141,3968,6302,1039,
.dw 4721,3968,3141,1103,15,3968,3150,1039,
.dw 15,3968,3973,1103,15,3968,3982,1039,
.dw 3328,4208,3983,1103,3328,4208,3983,1039,
.dw 3328,4208,8421,1103,3328,4208,8430,1039,
.dw 3328,4209,3333,1089,3328,4208,3342,1039,
.dw 4721,4208,4213,1089,15,4208,4222,1039,
.dw 15,4209,4222,1089,15,4208,4222,1103,
.dw 15,4208,8421,1103,15,4208,8430,1039,
.dw 4721,4208,3333,1089,15,4208,3342,1039,
.dw 15,4208,4213,1103,15,4208,4222,1039,
; Pattern 19:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 15,3136,3141,1089,15,3136,3150,1103,
.dw 4721,3137,4213,1103,15,3136,4222,1071,
.dw 15,2640,4223,1090,15,2640,4223,1103,
.dw 15,2640,6293,1103,15,2640,6302,1103,
.dw 4721,2096,3141,1103,15,2096,3150,1103,
.dw 15,2096,4213,1103,15,2096,4222,1039,
.dw 15,1872,4223,1103,15,1872,4223,1039,
.dw 15,1872,5605,1103,15,1872,5614,1039,
.dw 4721,1873,2805,1089,15,1872,2814,1039,
.dw 4721,1872,3749,1103,15,1872,3758,1039,
.dw 3141,2224,3759,1103,3141,2224,3759,1039,
.dw 3141,2224,5605,1103,3141,2224,5614,1039,
.dw 4721,2224,2805,1089,15,2224,2814,1039,
.dw 15,2224,3749,1103,15,2224,3758,1039,
.dw 3141,4720,3759,1103,3141,4720,3759,1039,
.dw 3141,4720,6293,1103,3141,4720,6302,1039,
.dw 4721,4721,3141,1089,15,4720,3150,1039,
.dw 3141,4720,3973,1103,3141,4720,3982,1039,
.dw 3141,4721,3982,1089,3141,4720,3982,1039,
.dw 3141,4720,6293,1103,3141,4720,6302,1039,
.dw 4721,4721,3141,1103,15,4720,3150,1039,
.dw 15,4720,3973,1103,15,4720,3982,1039,
.dw 3333,4208,3983,1103,3333,4208,3983,1039,
.dw 3333,4208,8421,1103,3333,4208,8430,1039,
.dw 3333,4208,3333,1089,3333,4208,3342,1039,
.dw 4721,4208,4213,1089,15,4208,4222,1039,
.dw 15,4208,4222,1089,15,4208,4222,1103,
.dw 15,4208,8421,1103,15,4208,8430,1039,
.dw 4721,4208,3333,1089,15,4208,3342,1039,
.dw 15,4208,4213,1103,15,4208,4222,1039,
; Pattern 20:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 15,3136,3141,1089,15,3136,3150,1103,
.dw 4721,3137,4213,1103,15,3136,4222,1071,
.dw 15,2640,4223,1090,15,2640,4223,1103,
.dw 15,2640,6293,1103,15,2640,6302,1103,
.dw 4721,2096,3141,1103,15,2096,3150,1103,
.dw 15,2096,4213,1103,15,2096,4222,1039,
.dw 15,2224,4223,1103,15,2224,4223,1039,
.dw 15,2224,5605,1103,15,2224,5614,1039,
.dw 4721,2225,2805,1089,15,2224,2814,1039,
.dw 4721,2224,3749,1103,15,2224,3758,1039,
.dw 3141,2800,3759,1103,3141,2800,3759,1039,
.dw 3141,2800,5605,1103,3141,2800,5614,1039,
.dw 4721,2800,2805,1089,15,2800,2814,1039,
.dw 15,2800,3749,1103,15,2800,3758,1039,
.dw 3970,4720,3759,1103,3970,4720,3759,1039,
.dw 3970,4720,6293,1103,3970,4720,6302,1039,
.dw 4721,4721,3141,1089,15,4720,3150,1039,
.dw 3970,4720,3973,1103,3970,4720,3982,1039,
.dw 3970,4721,3982,1089,3970,4720,3982,1039,
.dw 3970,4720,6293,1103,3970,4720,6302,1039,
.dw 4721,5296,3141,1103,15,5296,3150,1039,
.dw 15,5296,3973,1103,15,5296,3982,1039,
.dw 4210,6288,3983,1103,4210,6288,3983,1039,
.dw 4210,6288,6293,1103,4210,6288,6302,1039,
.dw 4210,6288,3141,1089,4210,6288,3150,1039,
.dw 4721,6289,4213,1089,15,6288,4222,1039,
.dw 15,6289,4222,1089,15,6288,4222,1103,
.dw 15,6288,6293,1103,15,6288,6302,1039,
.dw 4721,6288,3141,1089,15,6288,3150,1039,
.dw 15,6288,4213,1103,15,6288,4222,1039,
; Pattern 21:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 15,3137,3141,1103,15,3136,3150,1103,
.dw 3970,3136,4213,1103,3970,3136,4734,1071,
.dw 4721,2800,15,1089,15,2800,15,1103,
.dw 15,2800,6293,1103,15,2800,6302,1103,
.dw 15,2640,3141,1089,15,2640,3150,1103,
.dw 15,2640,4213,1103,15,2640,4222,1039,
.dw 4210,2800,4223,1103,4210,2800,4223,1039,
.dw 4210,2800,5605,1103,4210,2800,5614,1039,
.dw 4721,3328,2805,1103,15,3328,2814,1039,
.dw 4721,3328,3749,1103,15,3328,3758,1039,
.dw 4208,4208,3759,1089,4208,4208,3759,1039,
.dw 4208,4208,5605,1103,4208,4208,5614,1039,
.dw 4721,4209,2805,1089,15,4208,2814,1039,
.dw 15,4208,3749,1103,15,4208,3758,1039,
.dw 15,4720,3759,1090,15,4720,3759,1039,
.dw 15,4720,7957,1103,15,4720,7966,1039,
.dw 4721,4720,3973,1090,15,4720,3982,1039,
.dw 4721,4721,7957,1090,15,4720,7966,1039,
.dw 15,4208,7966,1089,15,4208,7966,1039,
.dw 15,4208,7957,1103,15,4208,7966,1039,
.dw 4721,3968,3973,1090,15,3968,3982,1039,
.dw 15,3968,3973,1103,15,3968,3982,1039,
.dw 15,4208,3983,1090,15,4208,3983,1039,
.dw 15,4208,8421,1103,15,4208,8430,1039,
.dw 4721,4208,3333,1103,15,4208,3342,1039,
.dw 4721,4208,4213,1090,15,4208,4222,1039,
.dw 15,4209,4222,1089,15,4208,4222,1103,
.dw 15,4208,8421,1103,15,4208,8430,1039,
.dw 4721,4208,3333,1090,15,4208,3342,1039,
.dw 15,4209,4213,1103,15,4208,4222,1039,
; Pattern 22:
.dw 4725,4720,15,1103,4725,4720,15,1039,
.dw 4725,4720,9461,1103,4725,4720,9470,1039,
.dw 4725,4720,4725,1089,4725,4720,4734,1103,
.dw 4720,4721,4725,1089,4720,4720,4734,1071,
.dw 4721,4208,4734,1089,15,4208,4734,1103,
.dw 15,4208,9461,1103,15,4208,9470,1103,
.dw 15,3968,4725,1089,15,3968,4734,1103,
.dw 15,3968,4725,1103,15,3968,4734,1039,
.dw 4213,4208,4735,1103,4213,4208,4735,1039,
.dw 4213,4208,8421,1103,4213,4208,8430,1039,
.dw 4213,4208,4213,1089,4213,4208,4222,1039,
.dw 4208,4208,4213,1103,4208,4208,4222,1039,
.dw 4213,4209,4222,1089,4213,4208,4222,1039,
.dw 4213,4720,8421,1103,4213,4720,8430,1039,
.dw 4721,5296,3973,1103,15,5296,3982,1039,
.dw 15,5600,4213,1103,15,5600,4222,1039,
.dw 5301,6288,4223,1089,5301,6288,4223,1039,
.dw 5301,6288,6293,1103,5301,6288,6302,1039,
.dw 4721,6288,3141,1089,15,6288,3150,1039,
.dw 4721,6288,4213,1103,15,6288,4222,1039,
.dw 15,6288,4222,1089,15,6288,4222,1039,
.dw 15,6288,6293,1103,15,6288,6302,1039,
.dw 4721,6289,3141,1103,15,6288,3150,1039,
.dw 15,4208,4213,1103,15,4208,4222,1039,
.dw 15,3136,4223,1089,15,3136,4223,1039,
.dw 15,3136,6293,1089,15,3136,6302,1039,
.dw 4721,3137,3141,1103,15,3136,3150,1039,
.dw 4721,3136,4213,1089,15,3136,4222,1039,
.dw 15,3328,4222,1089,15,3328,4222,1103,
.dw 15,3328,6293,1103,15,3328,6302,1039,
.dw 4721,3329,3141,1103,15,3328,3150,1039,
.dw 15,3328,4213,1103,15,3328,4222,1039,
; Pattern 23:
.dw 15,3136,15,1089,15,3136,15,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 4721,3136,3141,1089,15,3136,3150,1103,
.dw 3136,3136,4213,1103,3136,3136,4734,1071,
.dw 3136,3136,15,1089,3141,3136,15,1103,
.dw 3141,3136,6293,1103,3141,3136,6302,1103,
.dw 3136,3136,3141,1103,3136,3136,3150,1103,
.dw 3136,3136,4213,1103,3141,3136,4222,1039,
.dw 3141,3136,4223,1089,3141,3136,4223,1039,
.dw 3141,3136,6293,1103,3141,3136,6302,1039,
.dw 4721,3137,3141,1103,15,3136,3150,1039,
.dw 4721,3136,4213,1089,15,3136,4222,1039,
.dw 15,3136,4223,1089,15,3136,4223,1039,
.dw 15,3137,6293,1103,15,3136,6302,1039,
.dw 4721,3136,3141,1089,15,3136,3150,1039,
.dw 15,3136,4213,1103,15,3136,4222,1039,
.dw 15,3137,4223,1089,15,3136,4223,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 4721,3136,3141,1089,15,3136,3150,1039,
.dw 4721,3137,4213,1103,15,3136,4222,1039,
.dw 15,3136,4222,1089,15,3136,4222,1039,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 4721,3137,3141,1103,15,3140,3150,1039,
.dw 15,3144,4213,1103,15,3149,4222,1039,
.dw 15,3151,4223,1089,15,3151,4223,1039,
.dw 15,3151,6293,1103,15,3151,6302,1039,
.dw 4721,3136,3141,1103,15,3136,3150,1039,
.dw 4721,3136,4213,1089,15,3141,4222,1039,
.dw 15,3141,4222,1089,15,3141,4222,1103,
.dw 15,3136,6293,1103,15,3136,6302,1039,
.dw 4721,3136,3141,1089,15,3141,3150,1039,
.dw 15,3141,4213,1103,15,3141,4222,1039,
; Pattern 24:
.dw 6289,15,15,1088,6289,15,15,1039,
.dw 6289,15,6290,1103,6289,15,6290,1039,
.dw 3137,15,3141,1103,3137,15,3141,1103,
.dw 3137,15,4218,1088,3137,15,4218,1071,
.dw 4209,15,4218,1088,4209,15,4218,1103,
.dw 4209,15,6301,1103,4209,15,6301,1103,
.dw 5297,15,3149,1103,5297,15,3149,1103,
.dw 5297,15,4222,1103,5297,15,4222,1039,
.dw 6289,15,4222,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6289,15,4223,1039,
.dw 6289,15,4223,1103,6291,15,4223,1039,
.dw 6293,15,4223,1103,6296,15,4223,1039,
.dw 6299,15,4223,1103,6302,15,4223,1039,
.dw 6303,15,4223,1103,6303,15,4223,1039,
.dw 6302,15,4223,1103,6303,15,4223,1039,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,335,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
.dw 6303,15,4223,335,6303,15,4223,271,
; Pattern 25:
.dw 7073,7075,7074,1091,7073,15,7074,1039,
.dw 7073,15,7074,1097,7073,15,7074,1039,
.dw 3537,4723,7075,1097,3537,15,7074,1103,
.dw 3538,3539,3538,1091,3537,15,3538,1071,
.dw 3537,3542,3538,1097,3537,15,3538,1103,
.dw 3537,3539,7074,1091,3537,15,7074,1103,
.dw 3537,3542,3538,1091,3537,15,3538,1103,
.dw 3537,15,3538,1100,3537,15,4732,1039,
.dw 7073,15,3144,1091,7073,15,4213,1039,
.dw 3537,7075,4723,1091,3537,15,15,1039,
.dw 3537,15,15,1091,3537,15,15,1039,
.dw 7073,15,15,1103,7073,15,15,1039,
.dw 7489,7075,7490,1091,7489,15,7490,1039,
.dw 7489,15,7490,1096,7489,15,7490,1039,
.dw 3745,15,7491,1096,3745,15,7490,1039,
.dw 3746,15,3746,1091,3745,15,3746,1039,
.dw 3745,15,3746,1096,3745,15,3746,1039,
.dw 3745,15,7490,1091,3745,15,7490,1039,
.dw 3745,15,3746,1091,3745,15,3746,1039,
.dw 3745,15,3746,1100,3745,15,3746,1039,
.dw 7489,15,3139,1091,7489,15,3148,1039,
.dw 3745,15,3144,1091,3745,15,3141,1039,
.dw 3745,15,3747,1091,3745,15,4995,1039,
.dw 7489,15,7075,1091,7489,15,15,33807,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1103,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
.dw 7489,15,15,1103,7489,15,15,1039,
; Pattern 26:
.dw 4721,4725,9458,1859,4721,4725,9458,1807,
.dw 4721,4726,9459,1871,6289,4725,4722,1859,
.dw 4721,4725,4726,1871,4209,4726,4722,1859,
.dw 3969,4725,7954,1859,3969,4725,7955,1839,
.dw 3969,4726,7955,1871,4209,4725,6290,1859,
.dw 4209,4725,6290,1871,4209,4726,6290,1859,
.dw 4721,4725,6290,1859,4721,4725,6290,1871,
.dw 4721,5941,7074,1871,6289,5942,3538,1859,
.dw 4721,5941,3542,1871,3969,5942,3538,1859,
.dw 3137,5941,5938,1859,3137,5941,5939,1807,
.dw 3137,5942,5939,1871,3537,5941,4722,1859,
.dw 3537,5941,4722,1871,3537,5942,4722,1859,
.dw 3969,5941,4722,1859,3969,5941,4722,1807,
.dw 3969,4725,9458,1871,3970,4726,4722,1859,
.dw 3971,4725,4726,1871,3972,4726,4722,1859,
.dw 3137,4725,7954,1859,3137,4725,7955,1807,
.dw 3137,4726,7955,1871,3138,4725,6290,1859,
.dw 3139,4725,6290,1871,4721,4726,6290,1859,
.dw 4465,4725,6290,1859,4465,4725,6290,1807,
.dw 3969,4997,8930,1871,3537,4998,4466,1859,
.dw 3537,4997,4470,1871,2497,4998,4466,1859,
.dw 2497,4997,7074,1859,2497,4997,7075,1807,
.dw 2497,4998,7075,1871,2498,4997,5938,1859,
.dw 2499,4997,5938,1871,2501,4998,5938,34627,
.dw 2504,4997,5938,34627,2508,4997,5938,34575,
.dw 2508,4997,5938,1871,2508,4997,5938,1807,
.dw 2508,4997,5938,1871,2508,4997,5938,1807,
.dw 2508,4997,5938,1871,2508,4997,5938,1807,
.dw 2508,4997,5938,1871,2508,4997,5938,1871,
.dw 2508,4997,5938,1871,2508,4997,5938,1807,
.dw 2508,4997,5938,1871,2508,4997,5938,1807,
.dw 2508,4997,5938,1871,2508,4997,5938,1807,
; Pattern 27:
.dw 4721,15,15,1859,4721,15,15,1807,
.dw 4721,4725,9458,1871,6289,4726,4722,1859,
.dw 4721,4725,4726,1871,4209,4726,4722,1859,
.dw 3969,4725,7954,1859,3969,4725,7955,1839,
.dw 3969,4726,7955,1871,4209,4725,6290,1859,
.dw 4209,4725,6290,1871,4209,4726,6290,1859,
.dw 4721,4725,6290,1859,4721,4725,6290,1871,
.dw 4721,5941,5938,1871,6289,5942,5943,1859,
.dw 4721,5941,5943,1871,3969,5942,3330,1859,
.dw 3137,5941,3335,1859,3137,5941,3335,1807,
.dw 3137,5942,3538,1871,3537,5941,3970,1859,
.dw 3537,5941,3970,1871,3537,5942,3970,1859,
.dw 3969,5941,3970,1859,3969,5941,3970,1807,
.dw 3137,6293,6290,1871,3137,6294,6299,1859,
.dw 3137,6293,6299,1871,3137,6294,6290,1859,
.dw 2353,6293,6299,1859,2353,6293,6299,1807,
.dw 1985,6294,6290,1871,1985,6293,6290,1859,
.dw 1985,6293,6291,1871,1985,6294,6291,34627,
.dw 2353,6293,6292,34627,2353,6293,6293,1807,
.dw 2353,4997,4722,34639,2353,4998,4723,34627,
.dw 2353,4997,4722,1871,2353,4998,4722,1859,
.dw 2353,4997,4722,1859,2353,4997,4722,1807,
.dw 2353,4998,4722,1871,2353,4997,4722,1859,
.dw 2353,4997,4722,1871,2353,4998,4722,1859,
.dw 2353,4997,4722,34627,2353,4997,4722,34575,
.dw 2353,4997,4722,1871,2353,4997,4722,1807,
.dw 2353,4997,4722,1871,2353,4997,4722,1807,
.dw 2353,4997,4722,1871,2353,4997,4722,1807,
.dw 2353,4997,4722,1871,2353,4997,4722,1871,
.dw 2353,4997,4722,1871,2353,4997,4722,1807,
.dw 2353,4997,4722,1871,2353,4997,4722,1807,
.dw 2353,4997,4722,1871,2353,4997,4722,1807,
; Pattern 28:
.dw 2353,3968,15,1859,2353,3968,15,1807,
.dw 2353,4720,4722,1871,2354,3328,7954,1859,
.dw 2355,3328,7959,1871,2356,3136,7954,1859,
.dw 2357,3968,6290,1859,2359,3968,6290,1839,
.dw 2360,4720,6290,1871,4723,3328,4722,1859,
.dw 4723,3328,4722,1871,4724,3136,4722,1859,
.dw 4723,3968,4722,1859,4723,3968,4722,1871,
.dw 4724,4720,5938,1871,4724,3536,5938,1859,
.dw 4724,3536,5938,1871,4724,3328,5939,1859,
.dw 4725,3968,7954,1859,4725,3968,7954,1807,
.dw 4725,4720,7954,1871,4725,3536,5938,1859,
.dw 4726,3536,5938,1871,4726,3328,5938,1859,
.dw 4726,3968,5938,1859,4726,3968,5938,1807,
.dw 4728,4720,9458,1871,4728,3328,9458,1859,
.dw 4728,3328,9458,1871,4728,3136,9459,1859,
.dw 4730,3968,7954,1859,4730,3968,7954,1807,
.dw 4730,4720,7954,1871,4723,3328,6290,1859,
.dw 4723,3328,6290,1871,4724,3136,6290,1859,
.dw 4723,3968,6290,1859,4723,3968,6290,1807,
.dw 4724,4720,6290,1871,4724,3536,5938,1859,
.dw 4724,3536,5938,1871,4724,3328,5939,1859,
.dw 4725,3968,7954,1859,4725,3968,7954,1807,
.dw 4725,4720,7954,1871,4725,3536,5938,1859,
.dw 4726,3536,5938,1871,4726,3328,5938,34627,
.dw 4726,3968,5938,1859,4726,3968,5938,1807,
.dw 4728,3968,5938,34639,4728,3968,5938,1807,
.dw 4728,3968,5938,1871,4728,3968,5938,1807,
.dw 4728,3968,5938,1871,4728,3968,5938,1807,
.dw 4728,3968,5938,1871,4728,3968,5938,1871,
.dw 4728,3968,5938,1871,4728,3968,5938,1807,
.dw 4728,3968,5938,1871,4728,3968,5938,1807,
.dw 4728,3968,5938,1871,4728,3968,5938,1807,
; Pattern 29:
.dw 15,3968,15,1859,15,3968,15,1807,
.dw 15,4720,9458,1871,15,3328,9463,1859,
.dw 15,3328,9463,1871,15,3136,9458,1859,
.dw 15,3968,7954,1859,15,3968,7954,1839,
.dw 15,4720,7954,1871,4723,3328,6290,1859,
.dw 4723,3328,6290,1871,3331,3136,6290,1859,
.dw 3331,3968,6290,1859,3331,3968,6290,1871,
.dw 3332,4720,5938,1871,3332,3536,5943,1859,
.dw 3332,3536,5943,1871,3332,3328,5938,1859,
.dw 3333,3968,7954,1859,3333,3968,7954,1807,
.dw 3333,4720,7954,1871,3333,3536,9458,1859,
.dw 3333,3536,9458,1871,3331,3328,9458,1859,
.dw 3139,3968,9458,1859,3139,3968,9458,1807,
.dw 3140,4720,9458,1871,3140,3328,6290,1859,
.dw 3140,3328,6295,1871,3140,3136,6290,1859,
.dw 3139,3968,7954,1859,3139,3968,7954,1807,
.dw 3139,4720,7954,1871,3969,3328,9458,1859,
.dw 3969,3328,9458,1871,4209,3136,9458,1859,
.dw 4209,3968,9458,1859,4209,3968,9458,1807,
.dw 4209,4992,6290,1871,4209,3328,6295,1859,
.dw 4209,3328,6295,1871,4209,3136,6290,1859,
.dw 4209,4208,8418,1859,4209,4208,8418,1807,
.dw 4209,4992,8418,1871,4209,3328,6289,1859,
.dw 4209,3328,6289,1871,4209,3136,6289,1859,
.dw 4209,4208,6289,1859,4209,4208,6289,1807,
.dw 4209,4992,6289,34639,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1871,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
.dw 4209,4992,6289,1871,4209,4992,6289,1807,
; Pattern 30:
.dw 4726,4720,9458,1859,4731,4720,9458,1807,
.dw 4726,4722,9460,1864,4731,4722,9460,1871,
.dw 4726,4725,9463,1868,4731,4725,9463,1871,
.dw 4735,4730,9467,1871,4735,4730,9467,1839,
.dw 4735,4730,9467,1871,4735,4732,9469,1871,
.dw 4735,4734,9470,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,34639,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1871,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,
.dw 4735,4735,9471,1871,4735,4735,9471,1807,

.org $10000
.end
